@@ -38,7 +38,7 @@
 #include <QFileDialog>
 #include <QMimeData>
 #include <QApplication>
-#include <QDebug>
+#include "keditbookmarks_debug.h"
 
 #include <kactioncollection.h>
 #include <QIcon>
@@ -405,8 +405,8 @@ void ActionsImpl::slotInsertSeparator()
 
 void ActionsImpl::slotImport() {
     KEBApp::self()->bkInfo()->commitChanges();
-    qDebug() << "ActionsImpl::slotImport() where sender()->name() == "
-               << sender()->objectName() << endl;
+    qCDebug(KEDITBOOKMARKS_LOG) << "ActionsImpl::slotImport() where sender()->name() == "
+               << sender()->objectName();
     ImportCommand* import
         = ImportCommand::performImport(m_model, sender()->objectName(), KEBApp::self());
     if (!import)
@@ -477,9 +477,9 @@ public:
     KBookmarkGroupList(KBookmarkManager *);
     QList<KBookmark> getList(const KBookmarkGroup &);
 private:
-    void visit(const KBookmark &) Q_DECL_OVERRIDE {}
-    void visitEnter(const KBookmarkGroup &) Q_DECL_OVERRIDE;
-    void visitLeave(const KBookmarkGroup &) Q_DECL_OVERRIDE {}
+    void visit(const KBookmark &) override {}
+    void visitEnter(const KBookmarkGroup &) override;
+    void visitLeave(const KBookmarkGroup &) override {}
 private:
     KBookmarkManager *m_manager;
     QList<KBookmark> m_list;
